# travelperk-python-api-types
[![tag](https://img.shields.io/github/tag/namelivia/travelperk-python-api-types.svg)](https://github.com/namelivia/travelperk-python-api-types/releases) [![build](https://github.com/namelivia/travelperk-python-api-types/actions/workflows/build.yml/badge.svg)](https://github.com/namelivia/travelperk-python-api-types/actions/workflows/build.yml) [![codecov](https://codecov.io/gh/namelivia/travelperk-python-api-types/branch/main/graph/badge.svg?token=NlsLE3qD4V)](https://codecov.io/gh/namelivia/travelperk-python-api-types)
 [![Lint](https://github.com/namelivia/travelperk-python-api-types/actions/workflows/black.yml/badge.svg)](https://github.com/namelivia/travelperk-python-api-types/actions/workflows/black.yml)

<p align="center">
  <img src="https://user-images.githubusercontent.com/1571416/118358121-b78de000-b57d-11eb-9987-f750ed530d83.png" alt="TravelPerk API Types" />
</p>

## About
Python types for the TravelPerk API entities.

## Installation
